@@ -4,4 +4,7 @@ from typing import Optional
 class FetchParams(BaseModel):
     start_row: int
     end_row: int
-    sort: Optional[str] = None
\ No newline at end of file
+    sort: Optional[str] = None
+
+class FieldsParams(BaseModel):
+    with_categories: Optional[bool] = False
\ No newline at end of file
